package VMOMI::EntityImportType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
